@@ -23,6 +23,9 @@
 #include "DB/ImageInfo.h"
 #include "ImagePreview.h"
 #include <KPushButton>
+#include "config-kpa-kface.h"
+
+class QCheckBox;
 
 namespace AnnotationDialog
 {
@@ -42,6 +45,11 @@ public:
     ImagePreview *preview() const;
     bool showAreas() const;
     void canCreateAreas(bool state);
+    void setFacedetectButEnabled(bool state);
+#ifdef HAVE_KFACE
+    bool automatedTraining();
+#endif
+    void setSearchMode(bool state);
 
 public slots:
     void slotNext();
@@ -61,17 +69,26 @@ signals:
     void areaVisibilityChanged(bool visible);
 
 private:
-    ImagePreview* _preview;
-    KPushButton* _prevBut;
-    KPushButton* _nextBut;
-    KPushButton* _rotateLeft;
-    KPushButton* _rotateRight;
-    KPushButton* _delBut;
-    KPushButton* _copyPreviousBut;
-    KPushButton *_toggleAreasBut;
-    QList<DB::ImageInfo>* _imageList;
-    int _current;
-    bool _singleEdit;
+    /**
+     * Update labels and tooltip texts when canCreateAreas() changes.
+     */
+    void updateTexts();
+    ImagePreview* m_preview;
+    KPushButton* m_prevBut;
+    KPushButton* m_nextBut;
+    KPushButton* m_rotateLeft;
+    KPushButton* m_rotateRight;
+    KPushButton* m_delBut;
+    KPushButton* m_copyPreviousBut;
+    KPushButton *m_facedetectBut;
+    KPushButton *m_toggleAreasBut;
+    QList<DB::ImageInfo>* m_imageList;
+    int m_current;
+    bool m_singleEdit;
+#ifdef HAVE_KFACE
+    QCheckBox *m_autoTrainDatabase;
+#endif
+    QWidget* m_controlWidget;
 };
 
 }
