@@ -337,7 +337,7 @@ void AnnotationDialog::ResizableFrame::contextMenuEvent(QContextMenuEvent* event
             i18nc("As in: remove tag %1 in category %2 [from this marked area of the image]",
                   "Remove tag %1 (%2)",
                   m_tagData.second,
-                  DB::Category::localizedCategoryName(m_tagData.first))
+                  m_tagData.first)
         );
         menu->addAction(m_removeTagAct);
 
@@ -424,13 +424,10 @@ QAction* AnnotationDialog::ResizableFrame::createAssociateTagAction(
     if (! prefix.isEmpty()) {
         actionText = i18nc("%1 is a prefix like 'Associate with', "
                            "%2 is the tag name and %3 is the tag's category",
-                           "%1 %2 (%3)").arg(prefix,
-                                             tag.second,
-                                             DB::Category::localizedCategoryName(tag.first));
+                           "%1 %2 (%3)").arg(prefix, tag.second, tag.first);
     } else {
         actionText = i18nc("%1 is the tag name and %2 is the tag's category",
-                           "%1 (%2)").arg(tag.second,
-                                          DB::Category::localizedCategoryName(tag.first));
+                           "%1 (%2)").arg(tag.second, tag.first);
     }
 
     QAction* action = new QAction(actionText, this);
@@ -459,9 +456,7 @@ void AnnotationDialog::ResizableFrame::setTagData(QString category, QString tag,
     m_tagData = selectedData;
 
     // Update the tool tip
-    setToolTip(tag + QString::fromUtf8(" (") +
-               DB::Category::localizedCategoryName(category) +
-               QString::fromUtf8(")"));
+    setToolTip(tag + QString::fromUtf8(" (") + category + QString::fromUtf8(")"));
 
     // Set the color to "associated"
     setStyleSheet(STYLE_ASSOCIATED);
