@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2015 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -221,6 +221,10 @@ private:
     StackID m_stackId;
     unsigned int m_stackOrder;
     int m_videoLength;
+#ifdef HAVE_KGEOMAP
+    mutable KGeoMap::GeoCoordinates m_coordinates;
+    mutable bool m_coordsIsSet = false;
+#endif
 
     // Cache information
     bool m_locked;
