@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2015 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,10 @@
 #include "Exif/SearchInfo.h"
 #include <config-kpa-exiv2.h>
 #include "Utilities/Set.h"
-
+#include "config-kpa-kgeomap.h"
+#ifdef HAVE_KGEOMAP
+#  include <libkgeomap/geocoordinates.h>
+#endif
 namespace DB
 {
 
@@ -63,7 +66,7 @@ public:
     void addAnd( const QString& category, const QString& value );
     void setRating( short rating);
     QString toString() const;
- 
+
     void setMegaPixel( short megapixel );
     void setSearchRAW( bool m_searchRAW );
     void setSearchMode( int index );
@@ -79,6 +82,11 @@ public:
     void addExifSearchInfo( const Exif::SearchInfo info );
 #endif
 
+#ifdef HAVE_KGEOMAP
+    KGeoMap::GeoCoordinates::Pair regionSelection() const;
+    void setRegionSelection(const KGeoMap::GeoCoordinates::Pair& actRegionSelection);
+#endif
+
 protected:
     void compile() const;
     void deleteMatchers() const;
@@ -103,6 +111,15 @@ private:
 #ifdef HAVE_EXIV2
     Exif::SearchInfo m_exifSearchInfo;
 #endif
+
+#ifdef HAVE_KGEOMAP
+    KGeoMap::GeoCoordinates::Pair m_regionSelection;
+    mutable bool m_usingRegionSelection = false;
+    mutable float m_regionSelectionMinLat;
+    mutable float m_regionSelectionMaxLat;
+    mutable float m_regionSelectionMinLon;
+    mutable float m_regionSelectionMaxLon;
+#endif
     // When adding new instance variable, please notice that this class as an explicit written copy constructor.
 };
 
