@@ -350,8 +350,9 @@ QString SettingsData::albumCategory() const
     return category;
 }
 
-property_ref( untaggedCategory, setUntaggedCategory, QString, General, "Events")
-property_ref( untaggedTag,      setUntaggedTag,      QString, General, "untagged")
+property_ref( untaggedCategory, setUntaggedCategory, QString, General, i18n("Events"))
+property_ref( untaggedTag,      setUntaggedTag,      QString, General, i18n("untagged"))
+property_copy( untaggedImagesTagVisible, setUntaggedImagesTagVisible, bool, General, false);
 
 //////////////
 //// Exif ////
