@@ -25,14 +25,14 @@
 #include <DB/ImageDB.h>
 #include "DB/CategoryCollection.h"
 #include <QMessageBox>
+#include <QCheckBox>
 
 Settings::UntaggedGroupBox::UntaggedGroupBox( QWidget* parent )
     : QGroupBox( i18n("Untagged Images"), parent )
 {
     setWhatsThis(i18n("If a tag is selected here, it will be added to new (untagged) images "
                       "automatically, so that they can be easily found. It will be removed as "
-                      "soon as the image is annotated. This tag won't show up in the annotation "
-                      "dialog and can't be used for \"normal\" tagging."));
+                      "soon as the image has been annotated."));
 
     QGridLayout* grid = new QGridLayout(this);
     int row = -1;
@@ -51,6 +51,9 @@ Settings::UntaggedGroupBox::UntaggedGroupBox( QWidget* parent )
     grid->addWidget( m_tag, row, 1 );
     m_tag->setEditable(true);
 
+    m_showUntaggedImagesTag = new QCheckBox(i18n("Show the untagged images tag as a normal tag"));
+    grid->addWidget(m_showUntaggedImagesTag, ++row, 0, 1, 2);
+
     grid->setColumnStretch(1,1);
 }
 
@@ -60,7 +63,7 @@ void Settings::UntaggedGroupBox::populateCategoryComboBox()
     m_category->addItem( i18n("None Selected") );
     Q_FOREACH( DB::CategoryPtr category, DB::ImageDB::instance()->categoryCollection()->categories() ) {
         if (!category->isSpecialCategory() )
-            m_category->addItem( category->text(), category->name() );
+            m_category->addItem(category->name(), category->name());
     }
 }
 
@@ -101,7 +104,7 @@ void Settings::UntaggedGroupBox::loadSettings( Settings::SettingsData* opt )
         m_tag->setCurrentIndex( tagIndex );
     }
 
-
+    m_showUntaggedImagesTag->setChecked(opt->untaggedImagesTagVisible());
 }
 
 void Settings::UntaggedGroupBox::saveSettings( Settings::SettingsData* opt )
@@ -121,7 +124,7 @@ void Settings::UntaggedGroupBox::saveSettings( Settings::SettingsData* opt )
                      "<p>Please save now, so that this tag will be stored in the database. "
                      "Otherwise, it will be lost, and you will get an error about this tag being "
                      "not present on the next start.</p>",
-                     untaggedTag, DB::Category::localizedCategoryName(category)));
+                     untaggedTag, category));
         }
 
         opt->setUntaggedCategory(category);
@@ -131,6 +134,24 @@ void Settings::UntaggedGroupBox::saveSettings( Settings::SettingsData* opt )
         opt->setUntaggedCategory(QString());
         opt->setUntaggedTag(QString());
     }
+
+    opt->setUntaggedImagesTagVisible(m_showUntaggedImagesTag->isChecked());
+}
+
+void Settings::UntaggedGroupBox::categoryDeleted(QString categoryName)
+{
+    if (categoryName == m_category->itemData(m_category->currentIndex()).value<QString>()) {
+        m_category->setCurrentIndex(0);
+    }
+
+    m_category->removeItem(m_category->findText(categoryName));
+}
+
+void Settings::UntaggedGroupBox::categoryRenamed(QString oldCategoryName, QString newCategoryName)
+{
+    const int index = m_category->findText(oldCategoryName);
+    m_category->setItemText(index, newCategoryName);
+    m_category->setItemData(index, newCategoryName);
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
