@@ -37,11 +37,13 @@ namespace XMLDB {
         virtual QList<DB::CategoryPtr> categories() const;
         virtual void addCategory( const QString& text, const QString& icon, DB::Category::ViewType type,
                                   int thumbnailSize, bool show, bool positionable=false );
+        virtual DB::CategoryPtr categoryForSpecial( const DB::Category::CategoryType type) const;
 
         void initIdMap();
 
     private:
         QList<DB::CategoryPtr> m_categories;
+        QMap<DB::Category::CategoryType,DB::CategoryPtr> m_specialCategories;
     };
 }
 
